@@ -3,17 +3,9 @@ use strict;
 use warnings;
 use base 'Exporter';
 use CGI;
-use HTML::Shakan;
 
 our @EXPORT = qw(query trim);
 
-sub import {
-    strict->import;
-    warnings->import;
-
-    __PACKAGE__->export_to_level(1);
-}
-
 sub query { CGI->new(@_) }
 
 sub trim {
@@ -22,5 +14,4 @@ sub trim {
     $_;
 }
 
-
 1;
